# Template tags

Template-tags are python code safely callable from inside the html template.

In a template they are used as 

  {% mytagname args %s}

See the Django documentation on template tags and a lot of tags already coming
with Django. Placing code here allows for custom tags.
